@@ -73,7 +73,7 @@ SRATOM_LOG_FUNC(1, 2)
 static int
 test_fail(const char* fmt, ...)
 {
-  va_list args;
+  va_list args; // NOLINT(cppcoreguidelines-init-variables)
   va_start(args, fmt);
   fprintf(stderr, "error: ");
   vfprintf(stderr, fmt, args);
@@ -362,7 +362,7 @@ test(SerdEnv* env, bool top_level, bool pretty_numbers)
                                    LV2_ATOM_BODY(parsed));
     printf("# Turtle => Atom\n\n%s", instr);
 
-    if (strcmp(outstr, instr)) {
+    if (!!strcmp(outstr, instr)) {
       return test_fail("Re-serialized string differs from original\n");
     }
     free(instr);
